==> babel-preset-kiwicom-3.3.0.tgz: babel-preset-kiwicom/src/kiwicom-js-warning.js <==
"use strict";

/* eslint-disable flowtype/require-valid-file-annotation */
var getDevExpression = require('./getDevExpression');
/**
 * import { warning } from "@kiwicom/js";
 * warning(condition, argument, argument);
 *
 *      ↓ ↓ ↓ ↓ ↓ ↓
 *
 * import { warning } from "@kiwicom/js";
 * if (process.env.NODE_ENV !== "production") {
 *   warning(condition, argument, argument);
 * }
 *
 * This should then be removed by dead code elimination so these warnings are
 * not called in production at all.
 */


module.exports = function (_ref) {
  var t = _ref.types;
  var DEV_EXPRESSION = getDevExpression(t);
  var SEEN_SYMBOL = Symbol('SEEN_SYMBOL');
  return {
    pre: function pre() {
      this.canPerformChanges = false;
    },
    visitor: {
      ImportDeclaration: function ImportDeclaration(path) {
        if (path.node.source.value === '@kiwicom/js') {
          this.canPerformChanges = true;
        }
      },
      CallExpression: {
        enter: function enter(path) {
          if (path.get('callee').isIdentifier({
            name: 'require'
          })) {
            if (path.node.arguments[0].value === '@kiwicom/js') {
              this.canPerformChanges = true;
            }
          }
        },
        exit: function exit(path) {
          var node = path.node; // do nothing when testing

          if (process.env.NODE_ENV === 'test') {
            return;
          } // not our function


          if (this.canPerformChanges !== true) {
            return;
          } // ignore if it's already been processed


          if (node[SEEN_SYMBOL]) {
            return;
          }

          if (path.get('callee').isIdentifier({
            name: 'warning'
          })) {
            node[SEEN_SYMBOL] = true;
            path.replaceWith(t.ifStatement(DEV_EXPRESSION, t.blockStatement([t.expressionStatement(node)])));
          }
        }
      }
    }
  };
};

==> babel-preset-kiwicom-3.6.0.tgz: babel-preset-kiwicom/src/kiwicom-js-warning.js <==
"use strict";

/* eslint-disable flowtype/require-valid-file-annotation */
var buildDevExpression = require('./buildDevExpression');
/**
 * import { warning } from "@kiwicom/js";
 * warning(condition, argument, argument);
 *
 *      ↓ ↓ ↓ ↓ ↓ ↓
 *
 * import { warning } from "@kiwicom/js";
 * if (process.env.NODE_ENV !== "production") {
 *   warning(condition, argument, argument);
 * }
 *
 * This should then be removed by dead code elimination so these warnings are
 * not called in production at all.
 */


module.exports = function (babel) {
  var SEEN_SYMBOL = Symbol('SEEN_SYMBOL');
  return {
    pre: function pre() {
      this.canPerformChanges = false;
    },
    visitor: {
      ImportDeclaration: function ImportDeclaration(path) {
        if (path.node.source.value === '@kiwicom/js') {
          this.canPerformChanges = true;
        }
      },
      CallExpression: {
        enter: function enter(path) {
          if (path.get('callee').isIdentifier({
            name: 'require'
          })) {
            if (path.node.arguments[0].value === '@kiwicom/js') {
              this.canPerformChanges = true;
            }
          }
        },
        exit: function exit(path) {
          var node = path.node; // do nothing when testing

          if (process.env.NODE_ENV === 'test') {
            return;
          } // not our function


          if (this.canPerformChanges !== true) {
            return;
          } // ignore if it's already been processed


          if (node[SEEN_SYMBOL]) {
            return;
          }

          if (path.get('callee').isIdentifier({
            name: 'warning'
          })) {
            node[SEEN_SYMBOL] = true;
            path.replaceWith(babel.template("\n                if (%%condition%%) {\n                  %%conditionBody%%\n                }\n              ")({
              condition: buildDevExpression(babel),
              conditionBody: node
            }));
          }
        }
      }
    }
  };
};
